@@ -3,9 +3,12 @@
 #' release information.
 #' @return NEWS.md in viewer.
 #' @examples
+#' \dontrun{
 #' distr6News()
+#' }
 #' @export
-distr6News <- function (){
+distr6News <- function() {
   file.show(file.path(system.file(package = "distr6"), "NEWS.md"),
-            title = "distr6 Changelog")
+    title = "distr6 Changelog"
+  )
 }
